@@ -24,7 +24,7 @@
 
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-import datetime, json, math, os, re, select, shlex, time
+import datetime, errno, json, math, os, re, select, shlex, sys, time
 from subprocess import check_output, Popen, PIPE
 from xml.dom import minidom
 
@@ -55,7 +55,7 @@ class FFmpeg(object):
     encoding_executable = 'ffmpeg'
     parsing_executable = 'ffprobe'
 
-    def __init__(self, encoding_executable='ffmpeg', parsing_executable='ffprobe',
+    def __init__(self, encoding_executable=None, parsing_executable=None,
                  default_in_duration=datetime.timedelta(seconds=0), ratio_delta=0.01, time_delta=1, max_time_delta=5,
                  sanity_min_ratio=0.95, sanity_max_ratio=1.05, encoding='utf-8'):
         self.encoding_executable = encoding_executable or self.encoding_executable
@@ -108,6 +108,10 @@ class FFmpeg(object):
         args.extend(options + [out_filename])
         return args, in_filenames, out_filename, options
 
+    def _get_chunk(self, process):
+        select.select([process.stderr], [], [])
+        return process.stderr.read()
+
     def _get_process(self, arguments):
         """
         Return an encoding process with stderr made asynchronous.
@@ -402,8 +406,7 @@ class FFmpeg(object):
 
             while True:
                 # Wait for data to become available
-                select.select([process.stderr], [], [])
-                chunk = process.stderr.read()
+                chunk = self._get_chunk(process)
                 if not isinstance(chunk, string_types):
                     chunk = chunk.decode(self.encoding)
                 output += chunk
@@ -442,6 +445,11 @@ class FFmpeg(object):
                 fps=fps, bitrate=stats.get('bitrate'), quality=stats.get('q'),
                 sanity=self.sanity_min_ratio <= ratio <= self.sanity_max_ratio
             )
-        except:
-            process.kill()
-            raise
+        except Exception as exception:
+            tb = sys.exc_info()[2]
+            try:
+                process.kill()
+            except OSError as e:
+                if e.errno != errno.ESRCH:
+                    raise
+            raise exception.with_traceback(tb) if hasattr(exception, 'with_traceback') else exception
